@@ -20,6 +20,7 @@ class CodeGenerator(CodeGeneratorBase):
         *,
         lock_controller: bool = False,
         auth_features: bool = False,
+        for_git_repo: bool = False,
     ) -> None:
         # remove duplicate features
         if lock_controller:
@@ -43,7 +44,7 @@ class CodeGenerator(CodeGeneratorBase):
         generated_dir = join(package_dir, "generated")
         implementations_dir = join(package_dir, "feature_implementations")
 
-        self.generate_directory(out_dir)
+        self.generate_directory(out_dir, allow_overwrite=True)
         self.generate_directory(package_dir)
         self.generate_directory(generated_dir)
         self.generate_directory(implementations_dir)
@@ -52,6 +53,16 @@ class CodeGenerator(CodeGeneratorBase):
         self._generate_manifest(package_name, out_dir)
         self._generate_setup(package_name, out_dir)
 
+        # generate git repo files
+        if for_git_repo:
+            self.generate_file(
+                join(out_dir, ".gitignore"), self.template_env.get_template("package/gitignore").render()
+            )
+            self.generate_file(
+                join(out_dir, "README.md"),
+                self.template_env.get_template("package/readme").render(package_name=package_name),
+            )
+
         # generate package files
         self._generate_main(package_name, package_dir)
         self._generate_package_init(package_dir)
