@@ -118,7 +118,7 @@ class FeatureImplementationServicer:
             with raises_rpc_errors(context, self.logger, allowed_errors):
                 self.__apply_metadata_interceptors(None, metadata, cmd.fully_qualified_identifier)
                 response = impl_func(*params, metadata=metadata)
-                self.logger.info(f"Implementation returned {response}")
+                self.logger.info(f"Implementation returned {response!r}")
                 return cmd.responses.to_message(response)
 
         return wrapper
@@ -135,7 +135,7 @@ class FeatureImplementationServicer:
             with raises_rpc_errors(context, self.logger, allowed_errors):
                 self.__apply_metadata_interceptors(None, metadata, prop.fully_qualified_identifier)
                 response = impl_func(metadata=metadata)
-                self.logger.info(f"Implementation returned {response}")
+                self.logger.info(f"Implementation returned {response!r}")
                 return prop.to_message(response)
 
         return wrapper
@@ -157,7 +157,7 @@ class FeatureImplementationServicer:
                     metadata=metadata,
                     instance=instance,
                 )
-                self.logger.info(f"Implementation returned {response}")
+                self.logger.info(f"Implementation returned {response!r}")
                 return cmd.responses.to_message(response)
 
             command_manager = ObservableCommandManager(self.parent_server, cmd, _func_to_execute, metadata.keys())
@@ -181,6 +181,7 @@ class FeatureImplementationServicer:
             with raises_rpc_errors(context, self.logger):
                 for value in manager.subscribe_to_execution_infos(context):
                     yield value
+                self.logger.info(f"Cancelled by client: execution info subscription for {command_id}")
 
         return wrapper
 
@@ -194,6 +195,7 @@ class FeatureImplementationServicer:
             with raises_rpc_errors(context, self.logger):
                 for value in manager.subscribe_to_intermediate_responses(context):
                     yield value
+                self.logger.info(f"Cancelled by client: intermediate response subscription for {command_id}")
 
         return wrapper
 
@@ -235,6 +237,7 @@ class FeatureImplementationServicer:
 
                 for value in manager.add_subscription(context):
                     yield value
+                self.logger.info(f"Cancelled by client: observable property subscription for {property_id}")
 
         return wrapper
 
